BitmapHelper class

EXTRACTED FROM bitmap: ^0.0.6 DUE TO BUILD GRADLE INCOMPATIBILITIES

Constructors

BitmapHelper.blank(int width, int height)
BitmapHelper.fromHeadful(int width, int height, Uint8List headedIntList)
BitmapHelper.fromHeadless(int width, int height, Uint8List content)

Properties

content → Uint8List
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
no setter
width → int
final

Methods

buildHeaded() → Uint8List
buildImage() → Future<Image>
cloneHeadless() → BitmapHelper
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromProvider(ImageProvider<Object> provider) → Future<BitmapHelper>