LocalBitmapUtils class

Constructors

LocalBitmapUtils()
FACTORY METHODS *********************************************
factory
LocalBitmapUtils.private()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cleanMediaPath(String mediaPath) → String
inherited
getFromMediaAsset(String mediaPath) → ImageProvider<Object>
FACTORY METHODS *********************************************
getFromMediaFile(String mediaPath) → dynamic
inherited
getFromMediaNetwork(String mediaPath) → ImageProvider<Object>
getFromMediaPath(String mediaPath) → dynamic
inherited
getFromMediaResource(String mediaPath) → ImageProvider<Object>
getMediaSource(String? mediaPath) → MediaSource
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited