LocalDateUtils class

Constructors

LocalDateUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

localToUtc(DateTime date, {String format = 'yyyy-MM-dd HH:mm:ss'}) → DateTime
parseDateToString(DateTime? date, {String format = 'yyyy-MM-dd HH:mm:ss'}) → String?
parseStringToDate(String? date, {String format = 'yyyy-MM-dd HH:mm:ss'}) → DateTime?
utcToLocal(DateTime date, {String format = 'yyyy-MM-dd HH:mm:ss'}) → DateTime