cancelSchedulesByGroupKey method
Cancel all active schedules with the same group key, without dismiss the respective notifications on status bar
Implementation
@override
Future<void> cancelSchedulesByGroupKey(String groupKey) {
return LocalNotificationsPlatform.instance
.cancelSchedulesByGroupKey(groupKey);
}