MediaSourcePrefix class

Media source prefix, to identify which treatment should be done to each file path

Constructors

MediaSourcePrefix(int value)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

values → dynamic
no setter

Constants

Asset → const String
File → const String
Network → const String
Resource → const String
Unknown → const String