NotificationActionButton class

Notification button to display inside a notification. Since Android 7, icons are displayed only for Media Layout Notifications icon must be a native resource media type

Constructors

NotificationActionButton({required String key, required String label, String? icon, bool enabled = true, bool requireInputText = false, bool autoDismissible = true, bool showInCompactView = false, bool isDangerousOption = false, Color? color, ActionType actionType = ActionType.Default})

Properties

actionType → ActionType?
no setter
autoDismissible → bool?
no setter
color → Color?
no setter
enabled → bool?
no setter
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
no setter
isDangerousOption → bool?
no setter
key → String?
no setter
label → String?
no setter
requireInputText → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showInCompactView → bool?
no setter

Methods

fromMap(Map<String, dynamic> mapData) → NotificationActionButton?
Exports all content into a serializable object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Imports data from a serializable object
toString() → String
A string representation of this object.
inherited
validate() → void
Validates

Operators

operator ==(Object other) → bool
The equality operator.
inherited