millisecond property

  1. @Deprecated('Millisecond precision was deprecated, due devices do not provide or ignore such precision. The value will be ignored')
int? millisecond
getter/setter pair

Field number for get and set indicating the millisecond within the second.

Implementation

@Deprecated(
    'Millisecond precision was deprecated, due devices do not provide or ignore such precision. The value will be ignored')
int? millisecond;