NotificationChannel class

A representation of default settings that applies to all notifications with same channel key soundSource needs to be a native resource media type

Constructors

NotificationChannel({required String? channelKey, required String? channelName, required String? channelDescription, String? channelGroupKey, bool? channelShowBadge, NotificationImportance? importance, bool? playSound, String? soundSource, DefaultRingtoneType? defaultRingtoneType, bool? enableVibration, Int64List? vibrationPattern, bool? enableLights, Color? ledColor, int? ledOnMs, int? ledOffMs, String? groupKey, GroupSort? groupSort, GroupAlertBehavior? groupAlertBehavior, String? icon, Color? defaultColor, bool? locked, bool? onlyAlertOnce, NotificationPrivacy? defaultPrivacy, bool? criticalAlerts})

Properties

channelDescription ↔ String?
getter/setter pair
channelGroupKey ↔ String?
getter/setter pair
channelKey ↔ String?
getter/setter pair
channelName ↔ String?
getter/setter pair
channelShowBadge ↔ bool?
getter/setter pair
criticalAlerts ↔ bool?
getter/setter pair
defaultColor ↔ Color?
getter/setter pair
defaultPrivacy ↔ NotificationPrivacy?
getter/setter pair
defaultRingtoneType ↔ DefaultRingtoneType?
getter/setter pair
enableLights ↔ bool?
getter/setter pair
enableVibration ↔ bool?
getter/setter pair
groupAlertBehavior ↔ GroupAlertBehavior?
getter/setter pair
groupKey ↔ String?
getter/setter pair
groupSort ↔ GroupSort?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ String?
getter/setter pair
importance ↔ NotificationImportance?
getter/setter pair
ledColor ↔ Color?
getter/setter pair
ledOffMs ↔ int?
getter/setter pair
ledOnMs ↔ int?
getter/setter pair
locked ↔ bool?
getter/setter pair
onlyAlertOnce ↔ bool?
getter/setter pair
playSound ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
soundSource ↔ String?
getter/setter pair
stayOnScreen ↔ bool?
getter/setter pair
vibrationPattern ↔ Int64List?
getter/setter pair

Methods

fromMap(Map<String, dynamic> mapData) → NotificationChannel
Exports all content into a serializable object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Imports data from a serializable object
toString() → String
A string representation of this object.
inherited
validate() → void
Validates

Operators

operator ==(Object other) → bool
The equality operator.
inherited