NotificationContent class

Main content of notification If notification has no body or title, it will only be created, but not displayed to the user (background notification).

Constructors

NotificationContent({required int id, required String channelKey, String? title, String? body, String? groupKey, String? summary, String? icon, String? largeIcon, String? bigPicture, String? customSound, bool showWhen = true, bool wakeUpScreen = false, bool fullScreenIntent = false, bool criticalAlert = false, bool roundedLargeIcon = false, bool roundedBigPicture = false, bool autoDismissible = true, Color? color, Color? backgroundColor, ActionType actionType = ActionType.Default, NotificationLayout notificationLayout = NotificationLayout.Default, Map<String, String?>? payload, NotificationCategory? category, bool hideLargeIconOnExpand = false, bool locked = false, int? progress, int? badge, String? ticker, bool displayOnForeground = true, bool displayOnBackground = true})

Properties

actionType → ActionType?
no setterinherited
autoCancel → bool?
no setterinherited
autoDismissable → bool?
no setterinherited
autoDismissible → bool?
no setterinherited
backgroundColor → Color?
no setterinherited
badge → int?
no setter
bigPicture → String?
no setterinherited
bigPictureImage → ImageProvider<Object>?
no setterinherited
bigPicturePath → String?
no setterinherited
body → String?
no setterinherited
bodyWithoutHtml → String?
no setterinherited
category → NotificationCategory?
no setterinherited
channelKey → String?
no setterinherited
color → Color?
no setterinherited
createdDate ↔ DateTime?
getter/setter pairinherited
createdLifeCycle ↔ NotificationLifeCycle?
getter/setter pairinherited
createdSource ↔ NotificationSource?
getter/setter pairinherited
criticalAlert → bool?
no setterinherited
customSound → String?
no setterinherited
displayedDate ↔ DateTime?
getter/setter pairinherited
displayedLifeCycle ↔ NotificationLifeCycle?
getter/setter pairinherited
displayOnBackground → bool?
no setter
displayOnForeground → bool?
no setter
fullScreenIntent → bool?
no setterinherited
groupKey → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hideLargeIconOnExpand → bool?
no setter
icon → String?
no setterinherited
id → int?
no setterinherited
largeIcon → String?
no setterinherited
largeIconImage → ImageProvider<Object>?
no setterinherited
largeIconPath → String?
no setterinherited
locked → bool?
no setter
notificationLayout → NotificationLayout?
no setter
payload → Map<String, String?>?
no setterinherited
privacy → NotificationPrivacy?
no setterinherited
progress → int?
no setter
roundedBigPicture → bool?
no setterinherited
roundedLargeIcon → bool?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showWhen → bool?
no setterinherited
summary → String?
no setterinherited
ticker → String?
no setter
title → String?
no setterinherited
titleWithoutHtml → String?
no setterinherited
wakeUpScreen → bool?
no setterinherited

Methods

fromMap(Map<String, dynamic> mapData) → NotificationContent?
Exports all content into a serializable object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Imports data from a serializable object
toString() → String
A string representation of this object.
validate() → void
Validates
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited