NotificationSchedule class abstract

Notification schedule configuration timeZone: time zone reference to this schedule crontabExpression: Crontab expression as repetition rule (with seconds precision), as described in https://www.baeldung.com/cron-expressions allowWhileIdle: Determines if notification will send, even when the device is in critical situation, such as low battery.

Implementers

Constructors

NotificationSchedule({required String timeZone, bool allowWhileIdle = false, bool repeats = false, bool preciseAlarm = false})

Properties

allowWhileIdle ↔ bool
Displays the notification, even when the device is low battery
getter/setter pair
createdDate → String?
Reference
no setter
hashCode → int
The hash code for this object.
no setterinherited
preciseAlarm ↔ bool
Displays the notification at precise date, even when the device is low battery. Requires explicity permission in Android 12 and beyond.
getter/setter pair
repeats ↔ bool
Specify false to deliver the notification one time. Specify true to reschedule the notification request each time the notification is delivered.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeZone ↔ String
Full time zone identifier to schedule a notification, in english (ex: America/Sao_Paulo, America/New_York, Europe/Helsinki or GMT-07:00)
getter/setter pair

Methods

fromMap(Map<String, dynamic> mapData) → NotificationSchedule?
Returns null if invalid mapData is provided
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Imports data from a serializable object
toString() → String
A string representation of this object.
validate() → void
Validates
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited