RGBA32BitmapHeader class

Constructors

RGBA32BitmapHeader(int contentSize, int width, int height)

Properties

contentSize ↔ int
getter/setter pair
fileLength → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
headerIntList ↔ Uint8List
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyContent(Uint8List contentIntList) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited