ReceivedAction class

All received details of a user action over a Notification

Inheritance

Constructors

ReceivedAction()

Properties

actionDate ↔ DateTime?
getter/setter pair
actionLifeCycle ↔ NotificationLifeCycle?
getter/setter pair
actionType → ActionType?
no setterinherited
autoCancel → bool?
no setterinherited
autoDismissable → bool?
no setterinherited
autoDismissible → bool?
no setterinherited
backgroundColor → Color?
no setterinherited
bigPicture → String?
no setterinherited
bigPictureImage → ImageProvider<Object>?
no setterinherited
bigPicturePath → String?
no setterinherited
body → String?
no setterinherited
bodyWithoutHtml → String?
no setterinherited
buttonKeyInput ↔ String
getter/setter pair
buttonKeyPressed ↔ String
getter/setter pair
category → NotificationCategory?
no setterinherited
channelKey → String?
no setterinherited
color → Color?
no setterinherited
createdDate ↔ DateTime?
getter/setter pairinherited
createdLifeCycle ↔ NotificationLifeCycle?
getter/setter pairinherited
createdSource ↔ NotificationSource?
getter/setter pairinherited
criticalAlert → bool?
no setterinherited
customSound → String?
no setterinherited
dismissedDate ↔ DateTime?
getter/setter pair
dismissedLifeCycle ↔ NotificationLifeCycle?
getter/setter pair
displayedDate ↔ DateTime?
getter/setter pairinherited
displayedLifeCycle ↔ NotificationLifeCycle?
getter/setter pairinherited
fullScreenIntent → bool?
no setterinherited
groupKey → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
no setterinherited
id → int?
no setterinherited
largeIcon → String?
no setterinherited
largeIconImage → ImageProvider<Object>?
no setterinherited
largeIconPath → String?
no setterinherited
payload → Map<String, String?>?
no setterinherited
privacy → NotificationPrivacy?
no setterinherited
roundedBigPicture → bool?
no setterinherited
roundedLargeIcon → bool?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showWhen → bool?
no setterinherited
summary → String?
no setterinherited
title → String?
no setterinherited
titleWithoutHtml → String?
no setterinherited
wakeUpScreen → bool?
no setterinherited

Methods

fromMap(Map<String, dynamic> dataMap) → ReceivedAction
Imports data from a serializable object
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Exports all content into a serializable object
override
toString() → String
A string representation of this object.
inherited
validate() → void
Validates
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited